sequencetools.partition_sequence_extended_to_counts_without_overhang
====================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_extended_to_counts_without_overhang.partition_sequence_extended_to_counts_without_overhang
